yakumo.cinder.v2.snapshot

Package yakumo :: Package cinder :: Package v2 :: Module snapshot |
[hide private]
[frames] | no frames]

# Module snapshot

source code

Resource class and its manager for volume snapshots on Block Storage V2 API

Classes | [hide private]
| Resource resource class for volume snapshots on Block Storage V2 API
| Manager manager class for volume snapshots on Block Storage V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.cinder.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('name', 'name', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('description',
        'description',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('size', 'size', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('status',
        'status',
      ...